summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorPaul Eggert <eggert@cs.ucla.edu>2012-07-29 01:18:29 -0700
committerPaul Eggert <eggert@cs.ucla.edu>2012-07-29 01:18:29 -0700
commitb46a6a83b3c30d34aa6b80633394c74e6145291c (patch)
tree70cf89c43b7663acf77c2e54f2ed644d1eb18a4e /src
parent72b255c7e7856eb0abefb1149211a8be519f6fef (diff)
downloademacs-b46a6a83b3c30d34aa6b80633394c74e6145291c.tar.gz
Don't use the abbreviation "win" to refer to Windows (Bug#10421).
* lisp/org/ob-lilypond.el (ly-w32-ly-path): Rename from ly-win32-ly-path. (ly-w32-pdf-path): Rename from ly-win32-pdf-path. (ly-w32-midi-path): Rename from ly-win32-midi-path. (ly-determine-ly-path, ly-determine-pdf-path, ly-determine-midi-path): Check for "windows-nt", not "win32", in system-type. * src/regex.c (MAX_BUF_SIZE): Remove some incorrect and long-ago-commented-out code that talks about "WIN32". * src/w32heap.h (OS_WINDOWS_95): Rename from OS_WIN95. All uses changed.
Diffstat (limited to 'src')
-rw-r--r--src/ChangeLog8
-rw-r--r--src/ChangeLog.106
-rw-r--r--src/ChangeLog.113
-rw-r--r--src/ChangeLog.618
-rw-r--r--src/ChangeLog.78
-rw-r--r--src/ChangeLog.82
-rw-r--r--src/dbusbind.c2
-rw-r--r--src/makefile.w32-in2
-rw-r--r--src/regex.c14
-rw-r--r--src/sound.c2
-rw-r--r--src/w32.c6
-rw-r--r--src/w32console.c4
-rw-r--r--src/w32fns.c4
-rw-r--r--src/w32font.c6
-rw-r--r--src/w32font.h2
-rw-r--r--src/w32gui.h2
-rw-r--r--src/w32heap.c6
-rw-r--r--src/w32heap.h3
-rw-r--r--src/w32inevt.c2
-rw-r--r--src/w32inevt.h3
-rw-r--r--src/w32menu.c2
-rw-r--r--src/w32proc.c12
-rw-r--r--src/w32select.c2
-rw-r--r--src/w32term.c2
-rw-r--r--src/w32term.h2
-rw-r--r--src/w32xfns.c2
26 files changed, 59 insertions, 66 deletions
diff --git a/src/ChangeLog b/src/ChangeLog
index cc112f4b5da..21ba05adf6d 100644
--- a/src/ChangeLog
+++ b/src/ChangeLog
@@ -1,3 +1,11 @@
+2012-07-29 Paul Eggert <eggert@cs.ucla.edu>
+
+ Don't use the abbreviation "win" to refer to Windows (Bug#10421).
+ * regex.c (MAX_BUF_SIZE): Remove some incorrect and
+ long-ago-commented-out code that talks about "WIN32".
+ * w32heap.h (OS_WINDOWS_95): Rename from OS_WIN95.
+ All uses changed.
+
2012-07-28 Paul Eggert <eggert@cs.ucla.edu>
Use Gnulib stdalign module (Bug#9772, Bug#9960).
diff --git a/src/ChangeLog.10 b/src/ChangeLog.10
index cf62ec29bbc..6eda101c815 100644
--- a/src/ChangeLog.10
+++ b/src/ChangeLog.10
@@ -15825,7 +15825,7 @@
* w32term.c (w32_draw_fringe_bitmap): Copy unadapted code from
xterm.c to handle overlaid fringe bitmaps and to use cursor color
for displaying cursor in fringe.
- (w32_define_fringe_bitmap, w32_destroy_fringe_bitmap): New W32
+ (w32_define_fringe_bitmap, w32_destroy_fringe_bitmap): New Windows
specific functions to define and destroy fringe bitmaps in fringe_bmp.
(w32_redisplay_interface): Add them to redisplay_interface.
(w32_term_init): Call w32_init_fringe instead of explicitly
@@ -21476,7 +21476,7 @@
"Emacs built on Windows 9x/ME crashes at startup on Windows XP,
or Emacs builtpart of on XP crashes at startup on Windows 9x/ME."
- * w32.c: Added wrapper functions around the win32 API functions
+ * w32.c: Added wrapper functions around the Windows API functions
OpenProcessToken, GetTokenInformation, LookupAccountSid, and
GetSidIdentifierAuthority. These wrapper functions serve two
purposes:
@@ -21490,7 +21490,7 @@
the version of advapi32.dll that is found in the 9x branch of
Microsoft Windows.
- * w32.c (init_user_info): Replace the calls to the win32 API
+ * w32.c (init_user_info): Replace the calls to the Windows API
functions OpenProcessToken, GetTokenInformation, LookupAccountSid,
and GetSidIdentifierAuthority with calls to the newly added
wrapper functions.
diff --git a/src/ChangeLog.11 b/src/ChangeLog.11
index 781027ee8ae..d3b0a8284b5 100644
--- a/src/ChangeLog.11
+++ b/src/ChangeLog.11
@@ -3994,7 +3994,8 @@
2010-09-24 Juanma Barranquero <lekktu@gmail.com>
- Remove W32 API function pointer unused since 2005-02-15 (revno 2005-02-15T23:19:26Z!jasonr@gnu.org).
+ Remove Windows API function pointer unused since 2005-02-15 (revno
+ 2005-02-15T23:19:26Z!jasonr@gnu.org).
* w32fns.c (clipboard_sequence_fn): Don't declare.
(globals_of_w32fns): Don't initialize it.
diff --git a/src/ChangeLog.6 b/src/ChangeLog.6
index 3aa1a23818e..64f8b3a8314 100644
--- a/src/ChangeLog.6
+++ b/src/ChangeLog.6
@@ -1269,7 +1269,7 @@
"light", "extralight", and "thin" fonts.
(x_to_win32_charset, win32_to_x_charset): New functions.
(win32_to_x_font): Use new height units. Use win32_to_x_charset.
- (x_to_win32_font): Use x_to_win32_charset. Support Win32 font names
+ (x_to_win32_font): Use x_to_win32_charset. Support w32 font names
in addition to X font names.
(win32_load_font, Fx_list_fonts, Fx_display_color_cells)
@@ -3625,11 +3625,11 @@
* xdisp.c [HAVE_NTGUI] (set_menu_framebar): Declare external.
[HAVE_NTGUI] (frame_title_buf, frame_title_ptr): Include variables
- for Win32 window system.
+ for w32 window system.
[HAVE_NTGUI] (store_frame_title, x_consider_frame_title): Include
- procedures for Win32 window system.
- [HAVE_NTGUI] (x_consider_frame_title): Test for Win32 frame.
- [HAVE_NTGUI] (display_text_line): Test for Win32 frame on face change.
+ procedures for w32 window system.
+ [HAVE_NTGUI] (x_consider_frame_title): Test for w32 frame.
+ [HAVE_NTGUI] (display_text_line): Test for w32 frame on face change.
[HAVE_NTGUI] (display_menu_bar): Perform no-op for NT window system.
* window.c [HAVE_NTGUI] (Fset_window_configuration): Set menu
@@ -3659,7 +3659,7 @@
(make_lispy_event): Use FUNCTION_KEY_OFFSET to modify event codes
before applying modifiers.
- * frame.c [HAVE_NTGUI]: Test for a Win32 frame in procedures
+ * frame.c [HAVE_NTGUI]: Test for a w32 frame in procedures
that test for an X frame.
* frame.h (output_method): New method: output_win32.
@@ -3673,13 +3673,13 @@
* emacs.c [HAVE_NTGUI]: Declare Vwindow_system.
[HAVE_NTGUI] (main): Enable inhibit_window_system.
Initialize environment from registry.
- Declare syms of Win32 windowing modules.
+ Declare syms of w32 windowing modules.
* dispnew.c [HAVE_NTGUI]: Include w32term.h.
Include dispextern.h before cm.h since dispextern.h includes windows.h.
[HAVE_NTGUI] (make_frame_glyphs, free_frame_glyphs, scroll_frame_lines)
- (update_frame, update_line): Test for WIN32 frame.
- [HAVE_NTGUI] (init_display): Initialize WIN32 window system.
+ (update_frame, update_line): Test for w32 frame.
+ [HAVE_NTGUI] (init_display): Initialize w32 window system.
* dispextern.h [HAVE_NTGUI]: Include win32.h.
[HAVE_NTGUI] (struct frame_glyphs): Include pixel fields.
diff --git a/src/ChangeLog.7 b/src/ChangeLog.7
index 0952826e8c6..ce240ab2928 100644
--- a/src/ChangeLog.7
+++ b/src/ChangeLog.7
@@ -2070,7 +2070,7 @@
(sys_select): Ignore children dead children with pending input.
Delay sending SIGCHLD until all output has been read.
(sys_kill): Sleep to allow focus change events to propagate.
- Use TerminateProcess on Win95.
+ Use TerminateProcess on Windows 95.
(int_from_hex, enum_locale_fn, Fw32_get_valid_locale_ids):
New functions.
(Vw32_valid_locale_ids): New variable.
@@ -5719,13 +5719,13 @@
Loop over handles round robin to ensure fairness.
(sys_kill): Send ctrl-break and ctrl-c keystrokes to subprocesses
on SIGINT if not sharing consoles, otherwise generate ctrl-break event.
- On other termination signals, send WM_QUIT message to Win95 apps
+ On other termination signals, send WM_QUIT message to Windows 95 apps
and WM_CLOSE to NT apps.
(syms_of_ntproc): Intern new symbols. defsubr new functions.
DEFVAR new variables.
- * w32term.c (SIF_*): Win95 macros defined for NT.
- (struct tagSCROLLINFO): Win95 struct defined for NT.
+ * w32term.c (SIF_*): Windows 95 macros defined for NT.
+ (struct tagSCROLLINFO): Windows 95 struct defined for NT.
(vertical_scroll_bar_min_handle, vertical_scroll_bar_top_border)
(vertical_scroll_bar_bottom_border, last_scroll_bar_drag_pos)
(Vw32_gab_focus_on_raise, Vw32_capslock_is_shiftlock):
diff --git a/src/ChangeLog.8 b/src/ChangeLog.8
index d3ce1eb2a45..e68966b16a2 100644
--- a/src/ChangeLog.8
+++ b/src/ChangeLog.8
@@ -13203,7 +13203,7 @@
* w32.c (stat): GetFileInformationByHandle can legitimately fail,
so don't rely on it succeeding.
- * w32fns.c (x_to_w32_font): Specify DEFAULT_CHARSET in the w32
+ * w32fns.c (x_to_w32_font): Specify DEFAULT_CHARSET in the Windows
LOGFONT struct if x font doesn't specify the charset.
(x_to_w32_charset): Change >= to == when testing results of
stricmp.
diff --git a/src/dbusbind.c b/src/dbusbind.c
index 93388d4b24a..c1b1310454c 100644
--- a/src/dbusbind.c
+++ b/src/dbusbind.c
@@ -986,7 +986,7 @@ static int
xd_find_watch_fd (DBusWatch *watch)
{
#if HAVE_DBUS_WATCH_GET_UNIX_FD
- /* TODO: Reverse these on Win32, which prefers the opposite. */
+ /* TODO: Reverse these on w32, which prefers the opposite. */
int fd = dbus_watch_get_unix_fd (watch);
if (fd == -1)
fd = dbus_watch_get_socket (watch);
diff --git a/src/makefile.w32-in b/src/makefile.w32-in
index a2d1c36af64..ada19ccdca3 100644
--- a/src/makefile.w32-in
+++ b/src/makefile.w32-in
@@ -1,4 +1,4 @@
-# -*- Makefile -*- for GNU Emacs on the Microsoft W32 API.
+# -*- Makefile -*- for GNU Emacs on the Microsoft Windows API.
# Copyright (C) 2000-2012 Free Software Foundation, Inc.
# This file is part of GNU Emacs.
diff --git a/src/regex.c b/src/regex.c
index 4bf119402ac..43ee2c45212 100644
--- a/src/regex.c
+++ b/src/regex.c
@@ -1739,20 +1739,6 @@ static int analyse_first (re_char *p, re_char *pend,
be too small, many things would have to change. */
# define MAX_BUF_SIZE (1L << 15)
-#if 0 /* This is when we thought it could be 2^16 bytes. */
-/* Any other compiler which, like MSC, has allocation limit below 2^16
- bytes will have to use approach similar to what was done below for
- MSC and drop MAX_BUF_SIZE a bit. Otherwise you may end up
- reallocating to 0 bytes. Such thing is not going to work too well.
- You have been warned!! */
-#if defined _MSC_VER && !defined WIN32
-/* Microsoft C 16-bit versions limit malloc to approx 65512 bytes. */
-# define MAX_BUF_SIZE 65500L
-#else
-# define MAX_BUF_SIZE (1L << 16)
-#endif
-#endif /* 0 */
-
/* Extend the buffer by twice its current size via realloc and
reset the pointers that pointed into the old block to point to the
correct places in the new one. If extending the buffer results in it
diff --git a/src/sound.c b/src/sound.c
index 151bc1a08c1..403f08240ce 100644
--- a/src/sound.c
+++ b/src/sound.c
@@ -31,7 +31,7 @@ along with GNU Emacs. If not, see <http://www.gnu.org/licenses/>. */
cause an error to be generated.
The Windows implementation of play-sound is implemented via the
- Win32 API functions mciSendString, waveOutGetVolume, and
+ Windows API functions mciSendString, waveOutGetVolume, and
waveOutSetVolume which are exported by Winmm.dll.
*/
diff --git a/src/w32console.c b/src/w32console.c
index c3a1c5d86b3..76585851e7f 100644
--- a/src/w32console.c
+++ b/src/w32console.c
@@ -1,4 +1,4 @@
-/* Terminal hooks for GNU Emacs on the Microsoft W32 API.
+/* Terminal hooks for GNU Emacs on the Microsoft Windows API.
Copyright (C) 1992, 1999, 2001-2012 Free Software Foundation, Inc.
This file is part of GNU Emacs.
@@ -515,7 +515,7 @@ w32con_set_terminal_modes (struct terminal *t)
{
CONSOLE_CURSOR_INFO cci;
- /* make cursor big and visible (100 on Win95 makes it disappear) */
+ /* make cursor big and visible (100 on Windows 95 makes it disappear) */
cci.dwSize = 99;
cci.bVisible = TRUE;
(void) SetConsoleCursorInfo (cur_screen, &cci);
diff --git a/src/w32font.h b/src/w32font.h
index 40edafa146d..b08d48a3d36 100644
--- a/src/w32font.h
+++ b/src/w32font.h
@@ -1,4 +1,4 @@
-/* Shared GDI and Uniscribe Font backend declarations for the W32 API.
+/* Shared GDI and Uniscribe Font backend declarations for the Windows API.
Copyright (C) 2007-2012 Free Software Foundation, Inc.
This file is part of GNU Emacs.
diff --git a/src/w32gui.h b/src/w32gui.h
index 1e800e3cf3a..1ea185bfaa1 100644
--- a/src/w32gui.h
+++ b/src/w32gui.h
@@ -1,4 +1,4 @@
-/* Definitions and headers for communication on the Microsoft W32 API.
+/* Definitions and headers for communication on the Microsoft Windows API.
Copyright (C) 1995, 2001-2012 Free Software Foundation, Inc.
This file is part of GNU Emacs.
diff --git a/src/w32heap.h b/src/w32heap.h
index b2d51655098..7a20ba2a8b6 100644
--- a/src/w32heap.h
+++ b/src/w32heap.h
@@ -51,7 +51,7 @@ extern int w32_minor_version;
extern int w32_build_number;
enum {
- OS_WIN95 = 1,
+ OS_WINDOWS_95 = 1,
OS_NT
};
@@ -92,4 +92,3 @@ IMAGE_SECTION_HEADER * find_section (char * name, IMAGE_NT_HEADERS * nt_header);
IMAGE_SECTION_HEADER * rva_to_section (DWORD rva, IMAGE_NT_HEADERS * nt_header);
#endif /* NTHEAP_H_ */
-
diff --git a/src/w32inevt.c b/src/w32inevt.c
index 8d041194ca1..6d869727d2f 100644
--- a/src/w32inevt.c
+++ b/src/w32inevt.c
@@ -1,4 +1,4 @@
-/* Input event support for Emacs on the Microsoft W32 API.
+/* Input event support for Emacs on the Microsoft Windows API.
Copyright (C) 1992-1993, 1995, 2001-2012 Free Software Foundation, Inc.
This file is part of GNU Emacs.
diff --git a/src/w32inevt.h b/src/w32inevt.h
index 5386f2aa96c..c874e58ef39 100644
--- a/src/w32inevt.h
+++ b/src/w32inevt.h
@@ -1,4 +1,4 @@
-/* Input routines for GNU Emacs on the Microsoft W32 API.
+/* Input routines for GNU Emacs on the Microsoft Windows API.
Copyright (C) 1995, 2001-2012 Free Software Foundation, Inc.
This file is part of GNU Emacs.
@@ -30,4 +30,3 @@ extern void w32_console_mouse_position (FRAME_PTR *f, int insist,
unsigned long *time);
#endif /* EMACS_W32INEVT_H */
-
diff --git a/src/w32menu.c b/src/w32menu.c
index 871baedd0d3..09484d74b79 100644
--- a/src/w32menu.c
+++ b/src/w32menu.c
@@ -1,4 +1,4 @@
-/* Menu support for GNU Emacs on the Microsoft W32 API.
+/* Menu support for GNU Emacs on the Microsoft Windows API.
Copyright (C) 1986, 1988, 1993-1994, 1996, 1998-1999, 2001-2012
Free Software Foundation, Inc.
diff --git a/src/w32select.c b/src/w32select.c
index 1d4a6f41bdd..59ff4405368 100644
--- a/src/w32select.c
+++ b/src/w32select.c
@@ -1,4 +1,4 @@
-/* Selection processing for Emacs on the Microsoft W32 API.
+/* Selection processing for Emacs on the Microsoft Windows API.
Copyright (C) 1993-1994, 2001-2012 Free Software Foundation, Inc.
diff --git a/src/w32term.c b/src/w32term.c
index 6f0065de9eb..f02d101cea3 100644
--- a/src/w32term.c
+++ b/src/w32term.c
@@ -1,4 +1,4 @@
-/* Implementation of GUI terminal on the Microsoft W32 API.
+/* Implementation of GUI terminal on the Microsoft Windows API.
Copyright (C) 1989, 1993-2012 Free Software Foundation, Inc.
diff --git a/src/w32term.h b/src/w32term.h
index 4fdf560dabc..b49104dde8b 100644
--- a/src/w32term.h
+++ b/src/w32term.h
@@ -1,4 +1,4 @@
-/* Definitions and headers for communication on the Microsoft W32 API.
+/* Definitions and headers for communication on the Microsoft Windows API.
Copyright (C) 1995, 2001-2012 Free Software Foundation, Inc.
This file is part of GNU Emacs.
diff --git a/src/w32xfns.c b/src/w32xfns.c
index 0b0fc26fb6a..745a5cfe3e7 100644
--- a/src/w32xfns.c
+++ b/src/w32xfns.c
@@ -1,4 +1,4 @@
-/* Functions taken directly from X sources for use with the Microsoft W32 API.
+/* Functions taken directly from X sources for use with the Microsoft Windows API.
Copyright (C) 1989, 1992-1995, 1999, 2001-2012 Free Software Foundation, Inc.
This file is part of GNU Emacs.
diff --git a/src/w32.c b/src/w32.c
index 55b076e80f0..cd1d927e6fc 100644
--- a/src/w32.c
+++ b/src/w32.c
@@ -1,4 +1,4 @@
/* Utility and Unix shadow routines for GNU Emacs on the Microsoft W32 API.
Copyright (C) 1994-1995, 2000-2012 Free Software Foundation, Inc.
This file is part of GNU Emacs.
@@ -2011,7 +2011,7 @@ fdutimens (int fd, char const *file, struct timespec const timespec[2])
/* ------------------------------------------------------------------------- */
/* IO support and wrapper functions for W32 API. */
/* ------------------------------------------------------------------------- */
/* Place a wrapper around the MSVC version of ctime. It returns NULL
@@ -2929,7 +2929,7 @@ sys_rename (const char * oldname, const char * newname)
/* volume_info is set indirectly by map_w32_filename. */
oldname_dev = volume_info.serialnum;
- if (os_subtype == OS_WIN95)
+ if (os_subtype == OS_WINDOWS_95)
{
char * o;
char * p;
@@ -1,4 +1,4 @@
-/* Utility and Unix shadow routines for GNU Emacs on the Microsoft W32 API.
+/* Utility and Unix shadow routines for GNU Emacs on the Microsoft Windows API.
Copyright (C) 1994-1995, 2000-2012 Free Software Foundation, Inc.
This file is part of GNU Emacs.
@@ -2011,7 +2011,7 @@ fdutimens (int fd, char const *file, struct timespec const timespec[2])
/* ------------------------------------------------------------------------- */
-/* IO support and wrapper functions for W32 API. */
+/* IO support and wrapper functions for the Windows API. */
/* ------------------------------------------------------------------------- */
/* Place a wrapper around the MSVC version of ctime. It returns NULL
diff --git a/src/w32fns.c b/src/w32fns.c
index 1b1c5001344..97b7001a3fa 100644
--- a/src/w32fns.c
+++ b/src/w32fns.c
@@ -1,4 +1,4 @@
/* Graphical user interface functions for the Microsoft W32 API.
Copyright (C) 1989, 1992-2012 Free Software Foundation, Inc.
@@ -6575,7 +6575,7 @@ If the underlying system call fails, value is nil. */)
value = Qnil;
/* Determining the required information on Windows turns out, sadly,
- to be more involved than one would hope. The original Win32 api
+ to be more involved than one would hope. The original Windows API
call for this will return bogus information on some systems, but we
must dynamically probe for the replacement api, since that was
added rather late on. */
@@ -1,4 +1,4 @@
-/* Graphical user interface functions for the Microsoft W32 API.
+/* Graphical user interface functions for the Microsoft Windows API.
Copyright (C) 1989, 1992-2012 Free Software Foundation, Inc.
diff --git a/src/w32font.c b/src/w32font.c
index 81378825412..fd24a90d60b 100644
--- a/src/w32font.c
+++ b/src/w32font.c
@@ -1,4 +1,4 @@
/* Font backend for the Microsoft W32 API.
Copyright (C) 2007-2012 Free Software Foundation, Inc.
This file is part of GNU Emacs.
@@ -292,7 +292,7 @@ intern_font_name (char * string)
Lisp_Object str = DECODE_SYSTEM (build_string (string));
int len = SCHARS (str);
Lisp_Object obarray = check_obarray (Vobarray);
- Lisp_Object tem = oblookup (obarray, SDATA (str), len, len);
+ Lisp_Object tem = oblookup (obarray, SDATA (str), len, len);
/* This code is similar to intern function from lread.c. */
return SYMBOLP (tem) ? tem : Fintern (str, obarray);
}
@@ -1394,7 +1394,7 @@ font_matches_spec (DWORD type, NEWTEXTMETRICEX *font,
currently appear in fontset.el, so it isn't worth
creating a mapping table of codepages/scripts to languages
or opening the font to see if there are any language tags
- in it that the W32 API does not expose. Fontset
+ in it that the Windows API does not expose. Fontset
spec should have a fallback, as some backends do
not recognize language at all. */
return 0;
@@ -1,4 +1,4 @@
-/* Font backend for the Microsoft W32 API.
+/* Font backend for the Microsoft Windows API.
Copyright (C) 2007-2012 Free Software Foundation, Inc.
This file is part of GNU Emacs.
diff --git a/src/w32heap.c b/src/w32heap.c
index cc5e5cd2bf5..e34021b1099 100644
--- a/src/w32heap.c
+++ b/src/w32heap.c
@@ -1,4 +1,4 @@
/* Heap management routines for GNU Emacs on the Microsoft W32 API.
Copyright (C) 1994, 2001-2012 Free Software Foundation, Inc.
This file is part of GNU Emacs.
@@ -66,7 +66,7 @@ cache_system_info (void)
w32_minor_version = version.info.minor;
if (version.info.platform & 0x8000)
- os_subtype = OS_WIN95;
+ os_subtype = OS_WINDOWS_95;
else
os_subtype = OS_NT;
@@ -79,7 +79,7 @@ cache_system_info (void)
GetVersionEx (&osinfo_cache);
w32_build_number = osinfo_cache.dwBuildNumber;
- if (os_subtype == OS_WIN95)
+ if (os_subtype == OS_WINDOWS_95)
w32_build_number &= 0xffff;
}
@@ -1,4 +1,4 @@
-/* Heap management routines for GNU Emacs on the Microsoft W32 API.
+/* Heap management routines for GNU Emacs on the Microsoft Windows API.
Copyright (C) 1994, 2001-2012 Free Software Foundation, Inc.
This file is part of GNU Emacs.
diff --git a/src/w32proc.c b/src/w32proc.c
index afc1b21fdde..15b0ea25bc7 100644
--- a/src/w32proc.c
+++ b/src/w32proc.c
@@ -1,4 +1,4 @@
/* Process support for GNU Emacs on the Microsoft W32 API.
Copyright (C) 1992, 1995, 1999-2012 Free Software Foundation, Inc.
This file is part of GNU Emacs.
@@ -799,7 +799,7 @@ sys_spawnve (int mode, char *cmdname, char **argv, char **envp)
unixtodos_filename (cmdname);
argv[0] = cmdname;
/* Determine whether program is a 16-bit DOS executable, or a w32
executable that is implicitly linked to the Cygnus dll (implying it
was compiled with the Cygnus GNU toolchain and hence relies on
cygwin.dll to parse the command line - we use this to decide how to
@@ -1386,7 +1386,7 @@ find_child_console (HWND hwnd, LPARAM arg)
GetClassName (hwnd, window_class, sizeof (window_class));
if (strcmp (window_class,
- (os_subtype == OS_WIN95)
+ (os_subtype == OS_WINDOWS_95)
? "tty"
: "ConsoleWindowClass") == 0)
{
@@ -1517,7 +1517,7 @@ sys_kill (int pid, int sig)
if (NILP (Vw32_start_process_share_console) && cp && cp->hwnd)
{
#if 1
- if (os_subtype == OS_WIN95)
+ if (os_subtype == OS_WINDOWS_95)
{
/*
Another possibility is to try terminating the VDM out-right by
@@ -1536,7 +1536,7 @@ sys_kill (int pid, int sig)
*/
#if 0
/* On Win95, posting WM_QUIT causes the 16-bit subsystem
to hang when cmdproxy is used in conjunction with
command.com for an interactive shell. Posting
WM_CLOSE pops up a dialog that, when Yes is selected,
@@ -1810,7 +1810,7 @@ If successful, the return value is t, otherwise nil. */)
CHECK_NUMBER (process);
/* Allow pid to be an internally generated one, or one obtained
- externally. This is necessary because real pids on Win95 are
+ externally. This is necessary because real pids on Windows 95 are
negative. */
pid = XINT (process);
@@ -1,4 +1,4 @@
-/* Process support for GNU Emacs on the Microsoft W32 API.
+/* Process support for GNU Emacs on the Microsoft Windows API.
Copyright (C) 1992, 1995, 1999-2012 Free Software Foundation, Inc.
This file is part of GNU Emacs.
@@ -799,7 +799,7 @@ sys_spawnve (int mode, char *cmdname, char **argv, char **envp)
unixtodos_filename (cmdname);
argv[0] = cmdname;
- /* Determine whether program is a 16-bit DOS executable, or a w32
+ /* Determine whether program is a 16-bit DOS executable, or a 32-bit Windows
executable that is implicitly linked to the Cygnus dll (implying it
was compiled with the Cygnus GNU toolchain and hence relies on
@@ -1536,7 +1536,7 @@ sys_kill (int pid, int sig)
*/
#if 0
- /* On Win95, posting WM_QUIT causes the 16-bit subsystem
+ /* On Windows 95, posting WM_QUIT causes the 16-bit subsystem
to hang when cmdproxy is used in conjunction with
command.com for an interactive shell. Posting